# Mypy Type Check Coverage Summary

Summary from index
File | Imprecision | Lines
--- | --- | ---
Total | 18.03% imprecise | 1048 LOC
hatch_ci | 0.00% imprecise | 2 LOC
hatch_ci.cli | 19.85% imprecise | 136 LOC
hatch_ci.common | 0.00% imprecise | 1 LOC
hatch_ci.hooks | 37.50% imprecise | 8 LOC
hatch_ci.scm | 9.02% imprecise | 266 LOC
hatch_ci.script | 26.90% imprecise | 171 LOC
hatch_ci.tools | 20.52% imprecise | 385 LOC
hatch_ci.version_hook | 12.66% imprecise | 79 LOC